@@ -5,7 +5,7 @@ from textual.widgets import TextArea
 
 class TextAreaSnapshot(App):
     def compose(self) -> ComposeResult:
-        text_area = TextArea()
+        text_area = TextArea.code_editor()
         text_area.cursor_blink = False
         yield text_area
 
